#
# spec file for package dovecot23
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dovecot23
Version:        2.3.3
Release:        lp151.2.3.1
%define pkg_name dovecot
%define dovecot_version 2.3.3
%define dovecot_pigeonhole_version 0.5.3
%define dovecot_branch  2.3
%define dovecot_pigeonhole_source_dir %{pkg_name}-%{dovecot_branch}-pigeonhole-%{dovecot_pigeonhole_version}
%define dovecot_pigeonhole_docdir     %{_docdir}/%{pkg_name}/dovecot-pigeonhole
%define restart_flag /var/run/%{pkg_name}/%{pkg_name}-restart-after-rpm-install
%if 0%{?suse_version} > 1230
%bcond_without systemd
%bcond_with    textcat
%else
%bcond_with    systemd
%bcond_with    textcat
%endif
%bcond_without solr
%if 0%{?suse_version} > 1110
%bcond_without clucene
%bcond_without dcrypt_openssl
%bcond_without icu
%else
%bcond_with    clucene
%bcond_with    dcrypt_openssl
%bcond_with    icu
%endif
%bcond_without sqlite
%if 0%{?suse_version} >= 1110
%bcond_without lzma
%else
%bcond_with    lzma
%endif
%if 0%{?suse_version} >= 1320
%bcond_without lz4
%else
%bcond_with    lz4
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  cyrus-sasl-devel
BuildRequires:  flex
BuildRequires:  libapparmor-devel
%if %{with icu}
BuildRequires:  libicu-devel
%endif
BuildRequires:  libtool
%if %{with lzma}
BuildRequires:  xz-devel
%endif
%if %{with lz4}
BuildRequires:  liblz4-devel
%endif
BuildRequires:  libsodium-devel
BuildRequires:  mysql-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel
BuildRequires:  tcpd-devel
%if %{with sqlite}
BuildRequires:  sqlite-devel > 3
%endif
%if %{with clucene}
BuildRequires:  clucene-core-devel
BuildRequires:  gcc-c++
%endif
%if 0%{?sles_version} == 9
BuildRequires:  heimdal-devel
BuildRequires:  libcap
%else
BuildRequires:  krb5-devel
BuildRequires:  libcap-devel
%endif
%if 0%{?suse_version} > 1020
BuildRequires:  libbz2-devel
%endif
BuildRequires:  lua-devel
%if %{with solr}
BuildRequires:  curl-devel
BuildRequires:  libexpat-devel
%endif
%if %{with textcat}
BuildRequires:  libexttextcat-devel
%endif
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%define has_systemd 1
%endif
PreReq:         shadow %fillup_prereq
# bump requires on noarch package to the version which copies the files from /usr/share/dovecot/
Requires:       dovecot >= 2.3
Conflicts:      otherproviders(dovecot-implementation)
Provides:       dovecot-implementation = %{version}-%{release}
%if 0%{?suse_version} >= 1010
Recommends:     %{name}-backend-mysql = %{version}
Recommends:     %{name}-backend-pgsql = %{version}
%if %{with sqlite}
Recommends:     %{name}-backend-sqlite = %{version}
%endif
%endif
Recommends:     %{name}-fts = %{version}
Recommends:     %{name}-fts-squat = %{version}
Url:            http://www.dovecot.org
Source:         http://www.dovecot.org/releases/%{dovecot_branch}/%{pkg_name}-%{dovecot_version}.tar.gz
Source1:        http://pigeonhole.dovecot.org/releases/%{dovecot_branch}/%{dovecot_pigeonhole_source_dir}.tar.gz
Source2:        dovecot-rpmlintrc
Source3:        dovecot-2.0.configfiles
Source4:        dovecot-2.1.configfiles
Source5:        dovecot-2.2.configfiles
Source6:        dovecot-2.3.configfiles
Source7:        dovecot-2.1-pigeonhole.configfiles
Source8:        dovecot-2.2-pigeonhole.configfiles
Source9:        dovecot-2.3-pigeonhole.configfiles
Source10:       http://www.dovecot.org/releases/%{dovecot_branch}/%{pkg_name}-%{dovecot_version}.tar.gz.sig
Source11:       http://pigeonhole.dovecot.org/releases/%{dovecot_branch}/%{dovecot_pigeonhole_source_dir}.tar.gz.sig
Source12:       dovecot23.keyring
Patch:          dovecot-2.3.0-dont_use_etc_ssl_certs.patch
Patch1:         dovecot-2.3.0-better_ssl_defaults.patch
Summary:        IMAP and POP3 Server Written Primarily with Security in Mind
License:        BSD-3-Clause AND LGPL-2.1-or-later AND MIT
Group:          Productivity/Networking/Email/Servers

%description
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

%package backend-mysql
Requires:       %{name} = %{version}
Provides:       dovecot-backend-mysql = %{version}-%{release}
Provides:       dovecot_sql_backend = %{version}-%{release}
Conflicts:      otherproviders(dovecot-backend-mysql)
Summary:        MySQL support for Dovecot
Group:          Productivity/Networking/Email/Servers

%description backend-mysql
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the files needed for MySQL support.

%package backend-pgsql
Requires:       %{name} = %{version}
Provides:       dovecot-backend-pgsql = %{version}-%{release}
Provides:       dovecot_sql_backend = %{version}-%{release}
Conflicts:      otherproviders(dovecot-backend-pgsql)
Summary:        PostgreSQL support for Dovecot
Group:          Productivity/Networking/Email/Servers

%description backend-pgsql
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the files needed for PostgreSQL support.

%if %{with sqlite}

%package backend-sqlite
Requires:       %{name} = %{version}
Provides:       dovecot-backend-sqlite = %{version}-%{release}
Provides:       dovecot_sql_backend = %{version}-%{release}
Conflicts:      otherproviders(dovecot-backend-sqlite)
Summary:        SQLite support for Dovecot
Group:          Productivity/Networking/Email/Servers

%description backend-sqlite
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the files needed for SQLite support.

%endif

%package fts
Requires:       %{name} = %{version}
Summary:        Fulltext search support base plugin
Group:          Productivity/Networking/Email/Servers

%description fts
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the base plugin needed for fulltext search support

%package fts-squat
Requires:       %{name} = %{version}
Requires:       %{name}-fts = %{version}
Summary:        Fulltext search support squat plugin
Group:          Productivity/Networking/Email/Servers

%description fts-squat
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the files needed for fulltext search support squat plugin.


%if %{with clucene}

%package fts-lucene
Requires:       %{name} = %{version}
Requires:       %{name}-fts = %{version}
Provides:       dovecot-fts-clucene = %{version}-%{release}
Provides:       dovecot_fts_backend = %{version}-%{release}
Conflicts:      otherproviders(dovecot-fts-clucene)
Summary:        Fulltext search support via CLucene
Group:          Productivity/Networking/Email/Servers

%description fts-lucene
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the files needed for fulltext search support via CLucene.

%endif

%if %{with solr}

%package fts-solr
Requires:       %{name} = %{version}
Requires:       %{name}-fts = %{version}
Provides:       dovecot-fts-solr = %{version}-%{release}
Provides:       dovecot_fts_backend = %{version}-%{release}
Conflicts:      otherproviders(dovecot-fts-solr)
Summary:        Fulltext search support via solr
Group:          Productivity/Networking/Email/Servers

%description fts-solr
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the files needed for fulltext search support via solr.

%endif

%package devel
Requires:       %{name} = %{version}
Provides:       dovecot-devel = %{version}-%{release}
Conflicts:      otherproviders(dovecot-devel)
Summary:        Development files for Dovecot plugins
Group:          Development/Libraries/C and C++

%description devel
Dovecot is an IMAP and POP3 server for Linux and UNIX-like systems,
written primarily with security in mind. Although it is written in C,
it uses several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and is fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

This package holds the file needed to compile plugins outside of the
dovecot tree.

%prep
%setup -q -n %{pkg_name}-%{dovecot_version} -a 1
%patch -p1
%patch1 -p1
gzip -9v ChangeLog
# Fix plugins dir.
sed -i 's|#mail_plugin_dir = /usr/lib/dovecot|mail_plugin_dir = %{_libdir}/dovecot/modules|' doc/example-config/conf.d/10-mail.conf

%build
export CFLAGS="%{optflags}"
%if %{with clucene}
export CFLAGS="$CFLAGS -I%{_libdir}"
export CXXFLAGS="$CFLAGS -I%{_libdir}"
%endif
export CFLAGS="$CFLAGS -fpic -DPIC"
export LIBS="-pie"
%configure                                          \
    --docdir=%{_docdir}/%{pkg_name}                 \
    --with-moduledir=%{_libdir}/%{pkg_name}/modules \
    --libexecdir=%{_prefix}/lib/                    \
    --with-ioloop=best                              \
    --with-ldap=plugin                              \
    --with-sql=plugin                               \
    --with-gssapi=plugin                            \
    --with-pgsql                                    \
    --with-mysql                                    \
    --with-lua=plugin                               \
    --with-apparmor                                 \
%if %{with sqlite}
    --with-sqlite                                   \
%endif
%if %{with clucene}
    --with-lucene                                   \
%endif
%if %{with textcat}
    --with-textcat                                  \
%endif
%if %{with icu}
    --with-icu                                      \
%endif
%if %{with solr}
    --with-solr                                     \
%endif
    --with-ssl=openssl                              \
    --with-zlib                                     \
    --with-bzlib                                    \
%if %{with lzma}
    --with-lzma                                     \
%endif
%if %{with lz4}
    --with-lz4                                      \
%endif
    --with-libcap                                   \
    --with-libwrap                                  \
    --with-docs                                     \
%if %{with systemd}
    --with-systemdsystemunitdir=%{_unitdir}         \
%endif
    --disable-static
make %{?_smp_mflags}

pushd %{dovecot_pigeonhole_source_dir}
    %configure --with-dovecot=../ \
      --with-ldap=plugin \
      --docdir="%{dovecot_pigeonhole_docdir}"
    make %{?_smp_mflags}
popd

%check
make check
make -C %{dovecot_pigeonhole_source_dir} test

%install
%makeinstall
%makeinstall -C %{dovecot_pigeonhole_source_dir} sieve_docdir=%{dovecot_pigeonhole_docdir}

# clean up unused files, as much as I would like to use -delete ... the old find on sles9 doesnt support it
find %{buildroot}%{_libdir}/%{pkg_name}/ -type f \
	'(' -name \*.la -o -name \*.a ')' -print -delete

# create /var directories
install -m 0755 -Dd \
  %{buildroot}%{_var}/run/%{pkg_name}/login/ \
  %{buildroot}%{_var}/lib/%{pkg_name}/

# install the script to create dummy selfsigned certs
pushd %{buildroot}%{_docdir}/%{pkg_name}/
mv -v {*.cnf,mkcert.sh,example-config} ../../../%{pkg_name}/
install -m 755 -d example-config/conf.d/
ln -sv ../../../%{pkg_name}/{*.cnf,mkcert.sh} .
cd example-config/
ln -sv \
    ../../../../%{pkg_name}/example-config/*conf \
    ../../../../%{pkg_name}/example-config/*ext  \
  .
cd conf.d/
ln -sv \
    ../../../../../%{pkg_name}/example-config/conf.d/* \
  .
popd

# additional docs for the main package
install -m 0644 \
       AUTHORS ChangeLog* COPYING* NEWS TODO README* \
%if %{with solr}
    doc/*.xml \
%endif
    %{buildroot}%{_docdir}/%{pkg_name}/

# install sieve docs
install -m 0755 -Dd %{buildroot}%{dovecot_pigeonhole_docdir}
pushd %{dovecot_pigeonhole_source_dir}
sed -i 's/\r$//' doc/rfc/*
cp -av AUTHORS COPYING* INSTALL NEWS README TODO \
       examples/ doc/rfc/ doc/devel \
  %{buildroot}%{dovecot_pigeonhole_docdir}/
  rm %{buildroot}%{dovecot_pigeonhole_docdir}/rfc/Makefile*
popd

for i in $RPM_SOURCE_DIR/*.configfiles ; do
  echo "Creating ghost files for '$i'"
  for j in $(<$i) ; do
    install -D -m 0644 /dev/null %{buildroot}$j
  done
done

# clean up of things that are now in the unversioned package.
%if %{with systemd}
rm %{buildroot}%{_unitdir}/dovecot.{service,socket}
%endif
rm %{buildroot}%{_sysconfdir}/%{pkg_name}/README

%pre
test -n "$FIRST_ARG" || FIRST_ARG=$1
getent group %{pkg_name} >/dev/null || /usr/sbin/groupadd -r %{pkg_name}
getent passwd %{pkg_name} >/dev/null || \
	/usr/sbin/useradd -g %{pkg_name} -s /bin/false -r \
	-c "User for Dovecot imapd" -d %{_var}/run/%{pkg_name} %{pkg_name}
getent passwd dovenull >/dev/null || \
	/usr/sbin/useradd -g %{pkg_name} -s /bin/false -r \
	-c "User for Dovecot login" -d %{_var}/run/%{pkg_name} dovenull
# do not let dovecot run during upgrade rhbz#134325
if [ "$FIRST_ARG" -ge "1" ]; then
  rm -f %restart_flag
  %if %{with systemd}
    # we get installed before the unversioned dovecot package is installed
    # in that case we dont need to restart as there was no file to start us before
    if [ -x /bin/systemctl -a -e %{_unitdir}/%{pkg_name}.service ] ; then
      /bin/systemctl is-active %{pkg_name}.service >/dev/null 2>&1 && touch %restart_flag ||:
      /bin/systemctl stop      %{pkg_name}.service >/dev/null 2>&1
    fi
  %else
    # we get installed before the unversioned dovecot package is installed
    # in that case we dont need to restart as there was no file to start us before
    if [ -x /etc/init.d/%{pkg_name} ] ; then
      /etc/init.d/%{pkg_name} status >/dev/null 2>&1 && touch %restart_flag ||:
      /etc/init.d/%{pkg_name} stop >/dev/null 2>&1
    fi
  %endif
fi
# remove !SSLv2 from ssl_protocols (no longer supported in openssl-1.1.0)
if grep -s -q "ssl_protocols .*!SSLv2" /etc/dovecot/conf.d/10-ssl.conf; then
  sed -i 's/^\(ssl_protocols.*\)[[:blank:]]!SSLv2\(.*\)$/\1\2/g' /etc/dovecot/conf.d/10-ssl.conf
fi
%post -p /sbin/ldconfig

%postun
test -n "$FIRST_ARG" || FIRST_ARG=$1
/sbin/ldconfig
# do not let dovecot run during upgrade rhbz#134325
if [ "$FIRST_ARG" -ge "1" -a -e %restart_flag ]; then
  %if %{with systemd}
    # we get installed before the unversioned dovecot package is installed
    # in that case we dont need to restart as there was no file to start us before
    if [ -x /bin/systemctl -a -e %{_unitdir}/%{pkg_name}.service ] ; then
      /bin/systemctl start %{pkg_name}.service >/dev/null 2>&1 || :
    fi
  %else
    # we get installed before the unversioned dovecot package is installed
    # in that case we dont need to restart as there was no file to start us before
    if [ -x /etc/init.d/%{pkg_name} ] ; then
      /etc/init.d/%{pkg_name} start >/dev/null 2>&1 || :
    fi
  %endif
  rm -f %restart_flag
fi

# do not let dovecot run during upgrade rhbz#134325
# dovecot should be started again in %%postun, but it's not executed on reinstall
# if it was already started, restart_flag won't be here, so it's ok to test it again
%posttrans
if [ -e %restart_flag ]; then
  %if %{with systemd}
    # we get installed before the unversioned dovecot package is installed
    # in that case we dont need to restart as there was no file to start us before
    if [ -x /bin/systemctl -a -e %{_unitdir}/%{pkg_name}.service ] ; then
      /bin/systemctl start %{pkg_name}.service >/dev/null 2>&1 || :
    fi
  %else
    # we get installed before the unversioned dovecot package is installed
    # in that case we dont need to restart as there was no file to start us before
    if [ -x /etc/init.d/%{pkg_name} ] ; then
      /etc/init.d/%{pkg_name} start >/dev/null 2>&1 || :
    fi
  %endif
  rm -f %restart_flag
fi

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/%{pkg_name}/
%ghost %config(noreplace) /etc/dovecot/*
%{_sbindir}/%{pkg_name}
%{_bindir}/doveadm
%{_bindir}/doveconf
%{_bindir}/dsync
%{_bindir}/sieve-test
%{_bindir}/sievec
%{_bindir}/sieve-dump
%{_bindir}/sieve-filter
# subprocesses
%dir %{_prefix}/lib/%{pkg_name}
%{_prefix}/lib/%{pkg_name}/aggregator
%{_prefix}/lib/%{pkg_name}/anvil
%{_prefix}/lib/%{pkg_name}/auth
%{_prefix}/lib/%{pkg_name}/checkpassword-reply
%{_prefix}/lib/%{pkg_name}/config
%{_prefix}/lib/%{pkg_name}/decode2text.sh
%{_prefix}/lib/%{pkg_name}/deliver
%{_prefix}/lib/%{pkg_name}/dict
%{_prefix}/lib/%{pkg_name}/director
%{_prefix}/lib/%{pkg_name}/dns-client
%{_prefix}/lib/%{pkg_name}/doveadm-server
%{_prefix}/lib/%{pkg_name}/dovecot-lda
%{_prefix}/lib/%{pkg_name}/gdbhelper
%{_prefix}/lib/%{pkg_name}/imap
%{_prefix}/lib/%{pkg_name}/imap-hibernate
%{_prefix}/lib/%{pkg_name}/imap-login
%{_prefix}/lib/%{pkg_name}/imap-urlauth
%{_prefix}/lib/%{pkg_name}/imap-urlauth-login
%{_prefix}/lib/%{pkg_name}/imap-urlauth-worker
%{_prefix}/lib/%{pkg_name}/indexer
%{_prefix}/lib/%{pkg_name}/indexer-worker
%{_prefix}/lib/%{pkg_name}/ipc
%{_prefix}/lib/%{pkg_name}/lmtp
%{_prefix}/lib/%{pkg_name}/log
%{_prefix}/lib/%{pkg_name}/maildirlock
%{_prefix}/lib/%{pkg_name}/managesieve
%{_prefix}/lib/%{pkg_name}/managesieve-login
%{_prefix}/lib/%{pkg_name}/old-stats
%{_prefix}/lib/%{pkg_name}/pop3
%{_prefix}/lib/%{pkg_name}/pop3-login
%{_prefix}/lib/%{pkg_name}/quota-status
%{_prefix}/lib/%{pkg_name}/rawlog
%{_prefix}/lib/%{pkg_name}/replicator
%{_prefix}/lib/%{pkg_name}/script
%{_prefix}/lib/%{pkg_name}/script-login
%{_prefix}/lib/%{pkg_name}/stats
%{_prefix}/lib/%{pkg_name}/submission
%{_prefix}/lib/%{pkg_name}/submission-login
%{_prefix}/lib/%{pkg_name}/tcpwrap
%{_prefix}/lib/%{pkg_name}/xml2text
%{_libdir}/%{pkg_name}/libdovecot.so.*
%{_libdir}/%{pkg_name}/libdovecot-compression.so.*
%{_libdir}/%{pkg_name}/libdovecot-dsync.so.*
%{_libdir}/%{pkg_name}/libdovecot-fts.so.*
%{_libdir}/%{pkg_name}/libdovecot-lda.so.*
%{_libdir}/%{pkg_name}/libdovecot-ldap.so.*
%{_libdir}/%{pkg_name}/libdovecot-login.so.*
%{_libdir}/%{pkg_name}/libdovecot-sieve.so.*
%{_libdir}/%{pkg_name}/libdovecot-sql.so.*
%{_libdir}/%{pkg_name}/libdovecot-storage.so.*
%if %{with dcrypt_openssl}
%{_libdir}/%{pkg_name}/libdcrypt_openssl.so
%endif
# plugins
%dir %{_libdir}/%{pkg_name}
%dir %{_libdir}/%{pkg_name}/modules/
%{_libdir}/%{pkg_name}/modules/lib01_acl_plugin.so
%{_libdir}/%{pkg_name}/modules/lib01_apparmor_plugin.so
%{_libdir}/%{pkg_name}/modules/lib02_lazy_expunge_plugin.so
%{_libdir}/%{pkg_name}/modules/lib05_mail_crypt_acl_plugin.so
%{_libdir}/%{pkg_name}/modules/lib05_pop3_migration_plugin.so
%{_libdir}/%{pkg_name}/modules/lib05_snarf_plugin.so
%{_libdir}/%{pkg_name}/modules/lib10_last_login_plugin.so
%{_libdir}/%{pkg_name}/modules/lib10_mail_crypt_plugin.so
%{_libdir}/%{pkg_name}/modules/lib10_mail_filter_plugin.so
%{_libdir}/%{pkg_name}/modules/lib10_quota_plugin.so
%{_libdir}/%{pkg_name}/modules/lib11_trash_plugin.so
%{_libdir}/%{pkg_name}/modules/lib15_notify_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_mail_log_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_mailbox_alias_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_notify_status_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_charset_alias_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_expire_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_var_expand_crypt.so
%{_libdir}/%{pkg_name}/modules/lib20_zlib_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_push_notification_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_autocreate_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_listescape_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_quota_clone_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_replication_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_virtual_plugin.so
%{_libdir}/%{pkg_name}/modules/lib30_imap_zlib_plugin.so
%{_libdir}/%{pkg_name}/modules/lib02_imap_acl_plugin.so
%{_libdir}/%{pkg_name}/modules/lib11_imap_quota_plugin.so
%{_libdir}/%{pkg_name}/modules/lib90_sieve_plugin.so
%{_libdir}/%{pkg_name}/modules/lib90_old_stats_plugin.so
%{_libdir}/%{pkg_name}/modules/lib95_imap_sieve_plugin.so
%{_libdir}/%{pkg_name}/modules/lib95_imap_filter_sieve_plugin.so
%{_libdir}/%{pkg_name}/modules/lib95_imap_old_stats_plugin.so
%{_libdir}/%{pkg_name}/modules/lib99_welcome_plugin.so
%{_libdir}/%{pkg_name}/modules/libfs_compress.so
%{_libdir}/%{pkg_name}/modules/libfs_crypt.so
%{_libdir}/%{pkg_name}/modules/libfs_mail_crypt.so
%{_libdir}/%{pkg_name}/modules/libssl_iostream_openssl.so
#
%dir %{_libdir}/%{pkg_name}/modules/auth/
%{_libdir}/%{pkg_name}/modules/auth/libauthdb_imap.so
%{_libdir}/%{pkg_name}/modules/auth/libauthdb_ldap.so
%{_libdir}/%{pkg_name}/modules/auth/libauthdb_lua.so
%{_libdir}/%{pkg_name}/modules/auth/libmech_gssapi.so
%{_libdir}/%{pkg_name}/modules/auth/lib20_auth_var_expand_crypt.so
%dir %{_libdir}/%{pkg_name}/modules/dict/
%{_libdir}/%{pkg_name}/modules/dict/libdict_ldap.so
# more dict modules are in the sql packages
#
%dir %{_libdir}/%{pkg_name}/modules/doveadm
%{_libdir}/%{pkg_name}/modules/doveadm/libdoveadm_mail_crypt_plugin.so
%{_libdir}/%{pkg_name}/modules/doveadm/lib10_doveadm_acl_plugin.so
%{_libdir}/%{pkg_name}/modules/doveadm/lib10_doveadm_expire_plugin.so
%{_libdir}/%{pkg_name}/modules/doveadm/lib10_doveadm_quota_plugin.so*
%{_libdir}/%{pkg_name}/modules/doveadm/lib10_doveadm_sieve_plugin.so
#
%dir %{_libdir}/%{pkg_name}/modules/settings/
%{_libdir}/%{pkg_name}/modules/settings/libpigeonhole_settings.so
%{_libdir}/%{pkg_name}/modules/settings/libmanagesieve_login_settings.so
%{_libdir}/%{pkg_name}/modules/settings/libmanagesieve_settings.so
#
%dir %{_libdir}/%{pkg_name}/modules/sieve
%{_libdir}/%{pkg_name}/modules/sieve/lib10_sieve_storage_ldap_plugin.so
%{_libdir}/%{pkg_name}/modules/sieve/lib90_sieve_extprograms_plugin.so
%{_libdir}/%{pkg_name}/modules/sieve/lib90_sieve_imapsieve_plugin.so
#
%dir %{_libdir}/%{pkg_name}/modules/old-stats/
%{_libdir}/%{pkg_name}/modules/old-stats/libstats_auth.so
%{_libdir}/%{pkg_name}/modules/old-stats/libold_stats_mail.so
#
%dir %{_datadir}/%{pkg_name}/
%{_datadir}/%{pkg_name}/*.cnf
%{_datadir}/%{pkg_name}/mkcert.sh
%{_datadir}/%{pkg_name}/example-config
# doc
%{_mandir}/man1/deliver.1*
%{_mandir}/man1/doveadm*.1*
%{_mandir}/man1/doveconf.1*
%{_mandir}/man1/dovecot*.1*
%{_mandir}/man1/dsync.1*
%{_mandir}/man1/sieve-dump.1*
%{_mandir}/man1/sieve-filter.1*
%{_mandir}/man1/sieve-test.1*
%{_mandir}/man1/sievec.1*
%{_mandir}/man1/sieved.1*
%{_mandir}/man7/doveadm*.7*
%{_mandir}/man7/pigeonhole.7*
%doc %{_docdir}/%{pkg_name}
%if %{with solr}
%exclude %{_docdir}/%{pkg_name}/solr-schema.xml
%endif
# setting up permissions
%if ! %{with systemd}
%dir %attr(0755,root,root)        %ghost %{_var}/run/%{pkg_name}/
%dir %attr(0750,root,%{pkg_name}) %ghost %{_var}/run/%{pkg_name}/login/
%endif
%dir %attr(0750,root,root)        %{_var}/lib/%{pkg_name}/

%files fts
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/doveadm/lib20_doveadm_fts_plugin.so
%{_libdir}/%{pkg_name}/modules/lib20_fts_plugin.so
%{_datadir}/%{pkg_name}/stopwords/

%files fts-squat
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/lib21_fts_squat_plugin.so

%files backend-mysql
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/libdriver_mysql.so
%{_libdir}/%{pkg_name}/modules/auth/libdriver_mysql.so
%{_libdir}/%{pkg_name}/modules/dict/libdriver_mysql.so

%files backend-pgsql
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/libdriver_pgsql.so
%{_libdir}/%{pkg_name}/modules/auth/libdriver_pgsql.so
%{_libdir}/%{pkg_name}/modules/dict/libdriver_pgsql.so

%if %{with sqlite}
%files backend-sqlite
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/libdriver_sqlite.so
%{_libdir}/%{pkg_name}/modules/auth/libdriver_sqlite.so
%{_libdir}/%{pkg_name}/modules/dict/libdriver_sqlite.so
%endif

%if %{with clucene}
%files fts-lucene
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/lib21_fts_lucene_plugin.so
%{_libdir}/%{pkg_name}/modules/doveadm/lib20_doveadm_fts_lucene_plugin.so
%endif

%if %{with solr}
%files fts-solr
%defattr(-,root,root,-)
%{_libdir}/%{pkg_name}/modules/lib21_fts_solr_plugin.so
%{_docdir}/%{pkg_name}/solr-schema.xml
%endif

%files devel
%defattr(-,root,root,-)
%{_datadir}/aclocal/%{pkg_name}.m4
%{_datadir}/aclocal/dovecot-pigeonhole.m4
%{_includedir}/%{pkg_name}/
%{_libdir}/%{pkg_name}/dovecot-config
%{_libdir}/%{pkg_name}/libdovecot.so
%{_libdir}/%{pkg_name}/libdovecot-compression.so
%{_libdir}/%{pkg_name}/libdovecot-dsync.so
%{_libdir}/%{pkg_name}/libdovecot-fts.so
%{_libdir}/%{pkg_name}/libdovecot-lda.so
%{_libdir}/%{pkg_name}/libdovecot-ldap.so
%{_libdir}/%{pkg_name}/libdovecot-login.so
%{_libdir}/%{pkg_name}/libdovecot-sieve.so
%{_libdir}/%{pkg_name}/libdovecot-sql.so
%{_libdir}/%{pkg_name}/libdovecot-storage.so

%changelog
* Mon May 20 2019 Peter Varkoly <varkoly@suse.com>
- bsc#1134242 - upgrade from 42.3 to 15.1: dovecot shows Unknown
  protocol 'SSLv2'
  * remove !SSLv2 from existing ssl_protocols configuration
    during upgrade
* Mon Oct  1 2018 Marcus Rueckert <mrueckert@suse.de>
- update pigeonhole to 0.5.3
  - Fix assertion panic occurring when managesieve service fails to
    open INBOX while saving a Sieve script. This was caused by a
    lack of cleanup after failure.
  - Fix specific messages causing an assert panic with actions that
    compose a reply (e.g. vacation). With some rather weird input
    from the original message, the header folding algorithm (as
    used for composing the References header for the reply) got
    confused, causing the panic.
  - IMAP FILTER=SIEVE capability: Fix FILTER SIEVE SCRIPT command
    parsing.  After finishing reading the Sieve script, the command
    parsing sometimes didn't continue with the search arguments.
    This is a time- critical bug that likely only occurs when the
    Sieve script is sent in the next TCP frame.
* Mon Oct  1 2018 Marcus Rueckert <mrueckert@suse.de>
- update to 2.3.3
  * doveconf hides more secrets now in the default output.
  * ssl_dh setting is no longer enforced at startup. If it's not
    set and non-ECC DH key exchange happens, error is logged and
    client is disconnected.
  + Added log_debug=<filter> setting.
  + Added log_core_filter=<log filter> setting.
  + quota-clone: Write to dict asynchronously
  + --enable-hardening attempts to use retpoline Spectre 2
    mitigations
  + lmtp proxy: Support source_ip passdb extra field.
  + doveadm stats dump: Support more fields and output stddev
    by default.
  + push-notification: Add SSL support for OX backend.
  - NUL bytes in mail headers can cause truncated replies when
    fetched.
  - director: Conflicting host up/down state changes may in some
    rare situations ended up in a loop of two directors constantly
    overwriting each others' changes.
  - director: Fix hang/crash when multiple doveadm commands are
    being handled concurrently.
  - director: Fix assert-crash if doveadm disconnects too early
  - virtual plugin: Some searches used 100%% CPU for many seconds
  - dsync assert-crashed with acl plugin in some situations.
  - mail_attachment_detection_options=add-flags-on-save
    assert-crashed with some specific Sieve scripts.
  - Mail snippet generation crashed with mails containing invalid
    Content-Type:multipart header.
  - Log prefix ordering was different for some log lines.
  - quota: With noenforcing option current quota usage wasn't
    updated.
  - auth: Kerberos authentication against Samba assert-crashed.
  - stats clients were unnecessarily chatty with the stats server.
  - imapc: Fixed various assert-crashes when reconnecting to
    server.
  - lmtp, submission: Fix potential crash if client disconnects
    while handling a command.
  - quota: Fixed compiling with glibc-2.26 / support libtirpc.
  - fts-solr: Empty search values resulted in 400 Bad Request
    errors
  - fts-solr: default_ns parameter couldn't be used
  - submission server crashed if relay server returned over 7 lines
    in a reply (e.g. to EHLO)
- dropped 4ff4bd024a9b6e7973b76b186ce085c2ca669d3e.patch:
  included in update
* Fri Jul 13 2018 mrueckert@suse.de
- added
  https://github.com/dovecot/core/commit/4ff4bd024a9b6e7973b76b186ce085c2ca669d3e.patch
* Wed Jul 11 2018 mrueckert@suse.de
- update to 2.3.2.1
  - SSL/TLS servers may have crashed during client disconnection
  - lmtp: With lmtp_rcpt_check_quota=yes mail deliveries may have
    sometimes assert-crashed.
  - v2.3.2: "make check" may have crashed with 32bit systems
* Sat Jun 30 2018 mrueckert@suse.de
- update to 2.3.2
  * old-stats plugin: Don't temporarily enable PR_SET_DUMPABLE
    while opening /proc/self/io. This may still cause security
    problems if the process is ptrace()d at the same time.
    Instead, open it while still running as root.
  + doveadm: Added mailbox cache decision&remove commands. See
    doveadm-mailbox(1) man page for details.
  + doveadm: Added rebuild attachments command for rebuilding
    $HasAttachment or $HasNoAttachment flags for matching mails.
    See doveadm-rebuild(1) man page for details.
  + cassandra: Use fallback_consistency on more types of errors
  + lmtp proxy: Support outgoing SSL/TLS connections
  + lmtp: Add lmtp_rawlog_dir and lmtp_proxy_rawlog_dir settings.
  + submission: Add support for rawlog_dir
  + submission: Add submission_client_workarounds setting.
  + lua auth: Add password_verify() function and additional fields
    in auth request.
  - doveadm-server: TCP connections are hanging when there is a lot
    of network output. This especially caused hangs in
    dsync-replication.
  - Using multiple type=shared mdbox namespaces crashed
  - mail_fsync setting was ignored. It was always set to
    "optimized".
  - lua auth: Fix potential crash at deinit
  - SSL/TLS servers may have crashed if client disconnected during
    handshake.
  - SSL/TLS servers: Don't send extraneous certificates to client
    when alt certs are used.
  - lda, lmtp: Return-Path header without '<' may have
    assert-crashed.
  - lda, lmtp: Unencoded UTF-8 in email address headers may
    assert-crash
  - lda: -f parameter didn't allow empty/null/domainless address
  - lmtp, submission: Message size limit was hardcoded to 40 MB.
    Exceeding it caused the connection to get dropped during
    transfer.
  - lmtp: Fix potential crash when delivery fails at DATA stage
  - lmtp: login_greeting setting was ignored
  - Fix to work with OpenSSL v1.0.2f
  - systemd unit restrictions were too strict by default
  - Fix potential crashes when a lot of log output was produced
  - SMTP client may have assert-crashed when sending mail
  - IMAP COMPRESS: Send "end of compression" marker when
    disconnecting.
  - cassandra: Fix consistency=quorum to work
  - dsync: Lock file generation failed if home directory didn't
    exist
  - Snippet generation for HTML mails didn't ignore &entities
    inside blockquotes, producing strange looking snippets.
  - imapc: Fix assert-crash if getting disconnected and after
    reconnection all mails in the selected mailbox are gone.
  - pop3c: Handle unexpected server disconnections without
    assert-crash
  - fts: Fixes to indexing mails via virtual mailboxes.
  - fts: If mails contained NUL characters, the text around it
    wasn't indexed.
  - Obsolete dovecot.index.cache offsets were sometimes used.
    Trying to fetch a field that was just added to cache file may
    not have always found it.
- update pigeonhole to 0.5.2
  + Implement plugin for the a vendor-defined IMAP capability
    called "FILTER=SIEVE". It adds the ability to manually invoke
    Sieve filtering in IMAP. More information can be found in
    doc/plugins/imap_filter_sieve.txt.
  - The Sieve addess test caused an assertion panic for invalid
    addresses with UTF-8 codepoints in the localpart. Fixed by
    properly detecting invalid addresses with UTF-8 codepoints in
    the localpart and skipping these like other invalid addresses
    while iterating addresses for the address test.
  - Make the length of the subject header for the vacation response
    configurable and enforce the limit in UTF-8 codepoints rather
    than bytes. The subject header for a vacation response was
    statically truncated to 256 bytes, which is too limited for
    multi-byte UTF-8 characters.
  - Sieve editheader extension: Fix assertion panic occurring when
    it is used to manipulate a message header with a very large
    header field.
  - Properly abort execution of the sieve_discard script upon
    error.  Before, the LDA Sieve plugin attempted to execute the
    sieve_discard script when an error occurs. This can lead to the
    message being lost.
  - Fix the interaction between quota and the sieve_discard script.
    When quota was used together with a sieve_discard script, the
    message delivery did not bounce when the quota was exceeded.
- refreshed to apply cleanly again dovecot-2.3.0-better_ssl_defaults.patch
- dropped patches:
  - 35497604d80090a02619024aeec069b32568e4b4.diff
  - 5522b8b3d3ed1a99c3b63bb120216af0bd427403.diff
  - 847790d5aab84df38256a6f9b4849af0eb408419.patch
* Sun May 27 2018 mrueckert@suse.de
- added 847790d5aab84df38256a6f9b4849af0eb408419.patch:
  Fix crash for over quota users
* Thu May 24 2018 kbabioch@suse.com
- Use OpenPGP signatures provided upstream
- Added dovecot23.keyring, which contains the keys from the upstream projects
* Tue Apr 10 2018 varkoly@suse.com
- bnc#1088911 - dovecot23 can not build ond s390
  add: 35497604d80090a02619024aeec069b32568e4b4.diff
  add: 5522b8b3d3ed1a99c3b63bb120216af0bd427403.diff
* Wed Mar 28 2018 mrueckert@suse.de
- update pigeonhole to 0.5.1
  - Explicitly disallow UTF-8 in localpart in addresses parsed from
    Sieve script.
  - editheader extension: Corrected the stream position
    calculations performed while making the modified message
    available as a stream.  Pigeonhole Sieve crashed in LMTP with
    an assertion panic when the Sieve editheader extension was used
    before the message was redirected.  Experiments indicate that
    the problem occurred only with LMTP and that LDA is not
    affected.
  - fileinto extension: Fix assert panic occurring when fileinto is
    used without being listed in the require line, while the copy
    extension is listed there. This is a very old bug.
  - imapsieve plugin: Do not assert crash or log an error for
    messages that disappear concurrently while applying Sieve
    scripts. This event is now logged as a debug message.
  - Sieve extprograms plugin: Large output from "execute" command
    crashed delivery. Fixed buffering issue in code that handles
    output from the external program.
* Tue Mar 27 2018 mrueckert@suse.de
- update to 2.3.1
  * Submission server support improvements and bug fixes
  - Lots of bug fixes to submission server
  * API CHANGE: array_idx_modifiable will no longer allocate space
  - Particularly affects how you should check MODULE_CONTEXT
    result, or use REQUIRE_MODULE_CONTEXT.
  + mail_attachment_detection_options setting controls when
    $HasAttachment and $HasNoAttachment keywords are set for mails.
  + imap: Support fetching body snippets using FETCH (SNIPPET) or
    (SNIPPET (LAZY=FUZZY))
  + fs-compress: Automatically detect whether input is compressed
    or not.  Prefix the compression algorithm with "maybe-" to
    enable the detection, for example: "compress:maybe-gz:6:..."
  + Added settings to change dovecot.index* files' optimization
    behavior.  See https://wiki2.dovecot.org/IndexFiles#Settings
  + Auth cache can now utilize auth workers to do password hash
    verification by setting
    auth_cache_verify_password_with_worker=yes.
  + Added charset_alias plugin. See
    https://wiki2.dovecot.org/Plugins/CharsetAlias
  + imap_logout_format and pop3_logout_format settings now support
    all of the generic variables (e.g. %%{rip}, %%{session}, etc.)
  + Added auth_policy_check_before_auth,
    auth_policy_check_after_auth and auth_policy_report_after_auth
    settings.
  + master: Support HAProxy PP2_TYPE_SSL command and set "secured"
    variable appropriately
  - Invalid UCS4 escape in HTML can cause crashes
  - imap: IMAP COMPRESS -enabled client crashes on disconnect
  - lmtp: Fix crash when user is over quota
  - lib-lda: Parsing Return-Path header address fails when it
    contains CFWS
  - auth: SASL with Exim fails for AUTH commands without an initial
    response
  - imap: SPECIAL-USE capability isn't automatically added
  - auth: LDAP subqueries do not support standard auth variables in
    var-expand
  - auth: SHA256-CRYPT and SHA512-CRYPT schemes do not work
  - lib-index: mail_always/never_cache_fields are not used for
    existing cache files
  - imap: Fetching headers leaks memory if search doesn't find any
    mails
  - lmtp: ORCPT support in RCPT TO
  - imap-login: Process sometimes ends up in infinite loop
  - sdbox: Rolled back save/copy transaction doesn't delete temp
    files
  - mail: lock_method=dotlock causes crashes
- drop patches which are included in the update
  23da0fa1b30cc11bcc1d467674a0950c527e9ff1.patch
  dovecot-2.3.0.1-over-quota-lmtp-crash.patch
* Tue Mar 13 2018 dimstar@opensuse.org
- Fix License tag.
* Wed Mar  7 2018 mrueckert@suse.de
- added 23da0fa1b30cc11bcc1d467674a0950c527e9ff1.patch
* Wed Mar  7 2018 mrueckert@suse.de
- update license to SPDX-3
* Tue Mar  6 2018 mrueckert@suse.de
- update pigeonhole to 0.5.0.1
  - imap4flags extension: Fix binary corruption occurring when
    setflag/addflag/removeflag flag-list is a variable.
  - sieve-extprograms plugin: Fix segfault occurring when used in
    IMAPSieve context.
- drop 321a39be974deb2e7eff7b2a509a3ee6ff2e5ae1.patch
* Tue Mar  6 2018 mrueckert@suse.de
- pull backport patch dovecot-2.3.0.1-over-quota-lmtp-crash.patch
* Tue Mar  6 2018 mrueckert@suse.de
- update to 2.3.0.1
  * CVE-2017-15130: TLS SNI config lookups may lead to excessive
    memory usage, causing imap-login/pop3-login VSZ limit to be
    reached and the process restarted. This happens only if Dovecot
    config has local_name { } or local { } configuration blocks and
    attacker uses randomly generated SNI servernames. (boo#1082828)
  * CVE-2017-14461: Parsing invalid email addresses may cause a
    crash or leak memory contents to attacker. For example, these
    memory contents might contain parts of an email from another
    user if the same imap process is reused for multiple users.
    First discovered by Aleksandar Nikolic of Cisco Talos.
    Independently also discovered by "flxflndy" via HackerOne.
    (boo#1082826)
  * CVE-2017-15132: Aborted SASL authentication leaks memory in
    login process. (boo#1075608)
  * Linux: Core dumping is no longer enabled by default via
    PR_SET_DUMPABLE, because this may allow attackers to bypass
    chroot/group restrictions. Found by cPanel Security Team.
    Nowadays core dumps can be safely enabled by using "sysctl -w
    fs.suid_dumpable=2". If the old behaviour is wanted, it can
    still be enabled by setting:
    import_environment=$import_environment PR_SET_DUMPABLE=1
  - imap-login with SSL/TLS connections may end up in infinite loop
* Mon Dec 25 2017 jengelh@inai.de
- Replace %%__-type macro indirections.
  Replace xargs rm by built in -delete of find(1).
- Run ldconfig directly via %%post -p.
- Check for users in %%pre before creating them, and do not suppress
  errors about it.
* Mon Dec 25 2017 mrueckert@suse.de
- backport 321a39be974deb2e7eff7b2a509a3ee6ff2e5ae1.patch
  fixes crash with imap sieve
* Sun Dec 24 2017 mrueckert@suse.de
- Move the example-config + mkcert.sh to /usr/share/dovecot
  This makes the files no longer documentation and they actually
  exist on e.g. our docker image, where rpms are installed without
  documentation. (boo#1070871)
* Wed Dec 20 2017 mrueckert@suse.de
- starting 2.3 package based on the latest 2.2 branch
  There are several new and exciting features in v2.3.0. I'm
  especially happy about the new logging and statistics code, which
  will allow us to generate statistics for just about everything.
  We didn't have time to implement everything we wanted for them
  yet, and there especially aren't all that many logging events yet
  that can be used for statistics. We'll implement those to v2.3.1,
  which might also mean that some of the APIs might still change in
  v2.3.1 if that's required.
  We also have new lib-smtp server code, which was used to
  implement SMTP submission server and do a partial rewrite for
  LMTP server.
  Some of the larger changes:
  * Various setting changes, see
    https://wiki2.dovecot.org/Upgrading/2.3
    If you upgrade from 2.2: Config file changes:
  - Removed:
    /etc/dovecot/conf.d/11-object-storage.conf
  - Added:
    /etc/dovecot/conf.d/20-submission.conf
  * Logging rewrite started: Logging is now based on hierarchical
    events.  This makes it possible to do various things, like: 1)
    giving consistent log prefixes, 2) enabling debug logging with
    finer granularity, 3) provide logs in more machine readable
    formats (e.g. json). Everything isn't finished yet, especially
    a lot of the old logging code still needs to be translated to
    the new way.
  * Statistics rewrite started: Stats are now based on (log)
    events.  It's possible to gather statistics about any event
    that is logged.  See http://wiki2.dovecot.org/Statistics for
    details
  * ssl_dh setting replaces the old generated ssl-parameters.dat
  * IMAP: When BINARY FETCH finds a broken mails, send [PARSE]
    error instead of [UNKNOWNCTE]
  * Linux: core dumping via PR_SET_DUMPABLE is no longer enabled
    by default due to potential security reasons (found by cPanel
    Security Team).
  + Added support for SMTP submission proxy server, which
    includes support for BURL and CHUNKING extension.
  + LMTP rewrite. Supports now CHUNKING extension and mixing of
    local/proxy recipients.
  + auth: Support libsodium to add support for ARGON2I and
    ARGON2ID password schemes.
  + auth: Support BLF-CRYPT password scheme in all platforms
  + auth: Added LUA scripting support for passdb/userdb.
    See https://wiki2.dovecot.org/AuthDatabase/Lua
  - Input streams are more reliable now when there are errors or
    when the maximum buffer size is reached. Previously in some
    situations this could have caused Dovecot to try to read
    already freed memory.
  - Output streams weren't previously handling failures when
    writing a trailer at the end of the stream. This mainly
    affected encrypt and zlib compress ostreams, which could have
    silently written truncated files if the last write happened to
    fail (which shouldn't normally have ever happened).
  - virtual plugin: Fixed panic when fetching mails from virtual
    mailboxes with IMAP BINARY extension.
  - doveadm-server: Fix potential hangs with SSL connections
  - doveadm proxy: Reading commands' output from v2.2.33+ servers
    could have caused the output to be corrupted or caused a
    crash.
  - Many other smaller fixes
- patches:
  - dovecot-2.3.0-better_ssl_defaults.patch
  - dovecot-2.3.0-dont_use_etc_ssl_certs.patch
